@@ -145,14 +145,14 @@ class GenericFieldSet(BasicFieldSet):
 
         May raise a StopIteration() on error
         """
-        if config.debug:
-            self.info("[+] DBG: _addField(%s)" % field.name)
         if not issubclass(field.__class__, Field):
             raise ParserError("Field type (%s) is not a subclass of 'Field'!"
                 % field.__class__.__name__)
         assert isinstance(field._name, str)
         if field._name.endswith("[]"):
             self.setUniqueFieldName(field)
+        if config.debug:
+            self.info("[+] DBG: _addField(%s)" % field.name)
 
         # required for the msoffice parser
         if field._address != self._current_size:
@@ -178,7 +178,7 @@ class GenericFieldSet(BasicFieldSet):
 
         # No more place?
         dsize = self._checkSize(field._address + field.size, False)
-        if None < dsize < 0 or (field.is_field_set and field.size <= 0):
+        if (dsize is not None and dsize < 0) or (field.is_field_set and field.size <= 0):
             if self.autofix and self._current_size:
                 self._fixFieldSize(field, field.size + dsize)
             else:
